@@ -12,7 +12,7 @@ type ExpandRegexMatch struct {
 	Only   []string
 }
 
-var DefaultRefRegexp = regexp.MustCompile(`((secret)?ref)\+([^\+:]*://[^\+]+)\+?`)
+var DefaultRefRegexp = regexp.MustCompile(`((secret)?ref)\+([^\+:]*://[^\+\n]+)\+?`)
 
 func (e *ExpandRegexMatch) InString(s string) (string, error) {
 	var sb strings.Builder
@@ -60,9 +60,9 @@ func (e *ExpandRegexMatch) InMap(target map[string]interface{}) (map[string]inte
 		return nil, err
 	}
 
-	switch ret.(type) {
+	switch ret := ret.(type) {
 	case map[string]interface{}:
-		return ret.(map[string]interface{}), nil
+		return ret, nil
 	default:
 		return nil, fmt.Errorf("unexpected type: %v: %T", ret, ret)
 	}
